@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-07-26 18:31:06
-@LastEditTime: 2021-09-03 19:50:31
+@LastEditTime: 2021-09-07 10:26:43
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -92,14 +92,14 @@ class UpdateUserInfoHandler(TaoBaseHandler):
         open_id = self.get_taobao_param().open_id
         user_nick = self.get_taobao_param().user_nick
         act_id = int(self.get_param("act_id", 0))
-        tb_user_id = int(self.get_param("tb_user_id", 0))
+        user_id = int(self.get_param("tb_user_id", 0))
         avatar = self.get_param("avatar")
         is_member_before = int(self.get_param("is_member_before", -1))
         is_favor_before = int(self.get_param("is_favor_before", -1))
 
         invoke_result_data = InvokeResultData()
         user_base_model = UserBaseModel(context=self)
-        invoke_result_data = user_base_model.update_user_info(app_id, act_id, tb_user_id, open_id, user_nick, avatar, is_member_before, is_favor_before)
+        invoke_result_data = user_base_model.update_user_info(app_id, act_id, user_id, open_id, user_nick, avatar, is_member_before, is_favor_before)
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         else:
@@ -147,12 +147,12 @@ class ApplyBlackUnbindHandler(TaoBaseHandler):
         app_id = self.get_taobao_param().source_app_id
         open_id = self.get_taobao_param().open_id
         act_id = int(self.get_param("act_id", 0))
-        tb_user_id = int(self.get_param("tb_user_id", 0))
+        user_id = int(self.get_param("tb_user_id", 0))
         reason = self.get_param("reason", "误封号,申请解封")
 
         invoke_result_data = InvokeResultData()
         user_base_model = UserBaseModel(context=self)
-        invoke_result_data = user_base_model.apply_black_unbind(app_id, act_id, tb_user_id, open_id, reason)
+        invoke_result_data = user_base_model.apply_black_unbind(app_id, act_id, user_id, open_id, reason)
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         else:
@@ -234,11 +234,11 @@ class UserAssetListHandler(TaoBaseHandler):
         """
         app_id = self.get_taobao_param().source_app_id
         act_id = int(self.get_param("act_id", 0))
-        tb_user_id = int(self.get_param("tb_user_id", 0))
+        user_id = int(self.get_param("tb_user_id", 0))
         asset_type = int(self.get_param("asset_type", 0))
 
         asset_base_model = AssetBaseModel(context=self)
-        return self.response_json_success(asset_base_model.get_user_asset_list(app_id, act_id, tb_user_id, asset_type))
+        return self.response_json_success(asset_base_model.get_user_asset_list(app_id, act_id, user_id, asset_type))
 
 
 class AssetLogListHandler(TaoBaseHandler):
@@ -261,14 +261,14 @@ class AssetLogListHandler(TaoBaseHandler):
         app_id = self.get_taobao_param().source_app_id
         open_id = self.get_taobao_param().open_id
         act_id = int(self.get_param("act_id", 0))
-        tb_user_id = int(self.get_param("tb_user_id", 0))
+        user_id = int(self.get_param("tb_user_id", 0))
         page_index = int(self.get_param("page_index", 0))
         page_size = int(self.get_param("page_size", 20))
         asset_type = int(self.get_param("asset_type", 0))
         asset_object_id = self.get_param("asset_object_id")
 
         asset_base_model = AssetBaseModel(context=self)
-        return self.response_json_success(asset_base_model.get_asset_log_list(app_id, act_id, asset_type, page_size, page_index, tb_user_id, asset_object_id, "", "", "", open_id, 0, ""))
+        return self.response_json_success(asset_base_model.get_asset_log_list(app_id, act_id, asset_type, page_size, page_index, user_id, asset_object_id, "", "", "", open_id, 0, ""))
 
 
 class GetJoinMemberUrlHandler(TaoBaseHandler):
@@ -293,4 +293,3 @@ class GetJoinMemberUrlHandler(TaoBaseHandler):
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         return self.response_json_success(invoke_result_data.data)
-
