@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-03 15:42:53
-@LastEditTime: 2021-09-06 17:31:59
+@LastEditTime: 2021-09-06 19:16:57
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -45,9 +45,12 @@ class AddActInfoHandler(TaoBaseHandler):
     def get_async(self):
         """
         :description: 添加活动信息
+        :param app_id：应用标识
         :param act_name: 活动名称
         :param act_type: 活动类型
         :param theme_id: 主题标识
+        :param share_desc_json: 分享配置
+        :param rule_desc_json: 规则配置
         :param close_word: 关闭文案
         :last_editors: HuangJianYi
         """
@@ -56,9 +59,11 @@ class AddActInfoHandler(TaoBaseHandler):
         act_type = int(self.get_param("act_type", 0))
         theme_id = int(self.get_param("theme_id", 0))
         close_word = self.get_param("close_word","抱歉，程序维护中")
+        share_desc_json = self.get_param("share_desc_json", "")
+        rule_desc_json = self.get_param("rule_desc_json", "")
 
         act_base_model = ActBaseModel(context=self)
-        invoke_result_data = act_base_model.add_act_info(app_id, act_name,act_type,theme_id,"","",close_word)
+        invoke_result_data = act_base_model.add_act_info(app_id, act_name, act_type, theme_id, share_desc_json, rule_desc_json, close_word)
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         self.create_operation_log(OperationType.add.value, "act_info_tb", "AddActInfoHandler", None, self.json_dumps(invoke_result_data.data))
@@ -73,6 +78,7 @@ class UpdateActInfoHandler(TaoBaseHandler):
     def post_async(self):
         """
         :description: 修改活动信息
+        :param app_id：应用标识
         :param act_id：活动标识
         :param act_name：活动名称
         :param is_release：是否发布
@@ -148,6 +154,7 @@ class ActInfoListHandler(TaoBaseHandler):
     def get_async(self):
         """
         :description: 获取活动列表
+        :param app_id：应用标识
         :param act_name: 活动名称
         :param is_del: 是否回收站1是0否
         :param page_size: 条数
@@ -180,6 +187,7 @@ class ActInfoHandler(TaoBaseHandler):
     def get_async(self):
         """
         :description: 获取活动信息
+        :param app_id：应用标识
         :param act_id：活动标识
         :return:
         :last_editors: HuangJianYi
@@ -204,10 +212,11 @@ class DeleteActInfoHandler(TaoBaseHandler):
     """
     :description: 删除活动
     """
-    @filter_check_params("ct_id")
+    @filter_check_params("act_id")
     def get_async(self):
         """
         :description: 删除活动
+        :param app_id：应用标识
         :param act_id：活动标识
         :return: 
         :last_editors: HuangJianYi
@@ -230,6 +239,7 @@ class ReviewActInfoHandler(TaoBaseHandler):
     def get_async(self):
         """
         :description: 还原活动
+        :param app_id：应用标识
         :param act_id：活动标识
         :return: 
         :last_editors: HuangJianYi
@@ -253,6 +263,7 @@ class ReleaseActInfoHandler(TaoBaseHandler):
     def get_async(self):
         """
         :description: 上下架活动
+        :param app_id：应用标识
         :param act_id：活动标识
         :param is_release: 是否发布 1-是 0-否
         :return:
@@ -291,7 +302,7 @@ class NextProgressHandler(TaoBaseHandler):
     """
     :description: 下一步配置
     """
-    @filter_check_params("app_id,act_id,finish_key")
+    @filter_check_params("act_id,finish_key")
     def get_async(self):
         """
         :description: 下一步配置
