@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-03 10:43:58
-@LastEditTime: 2021-08-25 09:38:15
+@LastEditTime: 2021-09-06 19:11:57
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -62,7 +62,7 @@ class UpdateTelephoneHandler(TaoBaseHandler):
         check_code = self.get_param("check_code")
         modify_date = self.get_now_datetime()
 
-        check_code_re = self.redis_init().get("user_" + open_id + "_bind_phone_code")
+        check_code_re = SevenHelper.redis_init().get("user_" + open_id + "_bind_phone_code")
         if check_code_re == None:
             return self.response_json_error("error", "验证码已过期")
         check_code_re = str(check_code_re, 'utf-8')
