@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-07-26 17:00:55
-@LastEditTime: 2021-08-19 17:36:03
+@LastEditTime: 2021-09-07 09:10:26
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -130,7 +130,7 @@ class SendSmsHandler(TaoBaseHandler):
         result = dict(json.loads(response))
         result["result_code"] = result_code
         #记录验证码
-        self.redis_init().set("user_" + open_id + "_bind_phone_code", result_code, ex=300)
+        SevenHelper.redis_init().set("user_" + open_id + "_bind_phone_code", result_code, ex=300)
 
         return self.response_json_success()
 
