@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-02 11:03:56
-@LastEditTime: 2021-08-18 18:12:20
+@LastEditTime: 2021-09-07 09:12:14
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -16,7 +16,7 @@ class SaveIpInfoHandler(TaoBaseHandler):
     """
     :description: 保存IP信息
     """
-    @filter_check_params("act_id,ip_name,ip_pic")
+    @filter_check_params("act_id,ip_name")
     def get_async(self):
         """
         :description: 保存IP信息
