@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-09 14:11:52
-@LastEditTime: 2021-08-19 15:55:16
+@LastEditTime: 2021-09-07 09:26:37
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -10,7 +10,6 @@ from seven_cloudapp_frame.models.enum import *
 from seven_cloudapp_frame.libs.customize.oss2_helper import *
 from seven_cloudapp_frame.handlers.frame_base import *
 from seven_cloudapp_frame.models.order_base_model import *
-from seven_cloudapp_frame.models.seven_model import PageInfo
 
 
 class PayOrderListHandler(TaoBaseHandler):
@@ -57,6 +56,8 @@ class PrizeOrderListHandler(TaoBaseHandler):
         :description: 用户奖品订单列表
         :param app_id：应用标识
         :param act_id：活动标识
+        :param tb_user_id：用户标识
+        :param user_open_id：open_id
         :param order_no：订单号
         :param nick_name：用户昵称
         :param real_name：用户名字
@@ -65,10 +66,10 @@ class PrizeOrderListHandler(TaoBaseHandler):
         :param order_status：订单状态（-1未付款-2付款中0未发货1已发货2不予发货3已退款4交易成功）
         :param create_date_start：订单创建时间开始
         :param create_date_end：订单创建时间结束
-        :param page_size：页大小
-        :param page_index：页索引
         :param order_by：排序
         :param is_search_roster：是否查询订单关联中奖记录
+        :param page_size：页大小
+        :param page_index：页索引
         :return: 
         :last_editors: HuangJianYi
         """
@@ -102,10 +103,11 @@ class PrizeRosterListHandler(TaoBaseHandler):
     def get_async(self):
         """
         :description: 用户中奖记录列表
+        :param app_id：应用标识
         :param act_id：活动标识
         :param module_id：活动模块标识
-        :param user_id：用户标识
-        :param open_id：open_id
+        :param tb_user_id：用户标识
+        :param user_open_id：open_id
         :param user_nick：用户昵称
         :param order_no：订单号
         :param goods_type：物品类型（1虚拟2实物）
@@ -113,23 +115,21 @@ class PrizeRosterListHandler(TaoBaseHandler):
         :param logistics_status：物流状态（0未发货1已发货2不予发货）
         :param prize_status：奖品状态（0未下单（未领取）1已下单（已领取）2已回购10已隐藏（删除）11无需发货）
         :param pay_status：支付状态(0未支付1已支付2已退款3处理中)
-        :param page_size：页大小
-        :param page_index：页索引
         :param create_date_start：开始时间
         :param create_date_end：结束时间
+        :param page_size：页大小
+        :param page_index：页索引
         :return 
         :last_editors: HuangJianYi
         """
         app_id = self.get_app_id()
-        page_index = int(self.get_param("page_index", 0))
-        page_size = int(self.get_param("page_size", 500))
         act_id = int(self.get_param("act_id", 0))
         module_id = int(self.get_param("module_id", 0))
-        order_no = self.get_param("order_no")
         user_id = int(self.get_param("tb_user_id", 0))
-        user_nick = self.get_param("nick_name")
         user_open_id = self.get_param("user_open_id")
-        is_order = self.get_param("is_order")
+        order_no = self.get_param("order_no")
+        user_nick = self.get_param("nick_name")
+        is_order = self.get_param("is_order",False)
         goods_type = int(self.get_param("goods_type", -1))
         prize_type = int(self.get_param("prize_type", -1))
         logistics_status = int(self.get_param("logistics_status", -1))
@@ -137,6 +137,8 @@ class PrizeRosterListHandler(TaoBaseHandler):
         pay_status = int(self.get_param("pay_status", -1))
         create_date_start = self.get_param("create_date_start")
         create_date_end = self.get_param("create_date_end")
+        page_index = int(self.get_param("page_index", 0))
+        page_size = int(self.get_param("page_size", 500))
         if is_order:
             prize_status = 1
         order_base_model = OrderBaseModel(context=self)
@@ -148,12 +150,12 @@ class UpdatePrizeOrderSellerRemarkHandler(TaoBaseHandler):
     :description: 更新奖品订单卖家备注
     """
     @filter_check_params("prize_order_id")
-    def post_async(self):
+    def get_async(self):
         """
         :description: 更新奖品订单卖家备注
         :param app_id：应用标识
         :param prize_order_id：奖品订单标识
-        :param remarks：卖家备注
+        :param seller_remark：卖家备注
         :return: 
         :last_editors: HuangJianYi
         """
@@ -172,7 +174,7 @@ class UpdatePrizeOrderStatusHandler(TaoBaseHandler):
     :description: 更新用户奖品订单状态
     """
     @filter_check_params("prize_order_id,order_status")
-    def post_async(self):
+    def get_async(self):
         """
         :description: 更新用户奖品订单状态
         :param app_id：应用标识
@@ -203,7 +205,7 @@ class ImportPrizeOrderHandler(TaoBaseHandler):
     @filter_check_params("content,act_id")
     def post_async(self):
         """
-        :description: 
+        :description: 导入奖品订单进行发货
         :param app_id：应用标识
         :param content：base64加密后的excel内容
         :param act_id：活动标识
@@ -231,13 +233,21 @@ class PrizeOrderExportHandler(TaoBaseHandler):
     def get_async(self):
         """
         :description: 导出奖品订单列表
-        :param page_index：页索引
-        :param page_size：页大小
-        :param act_id：活动id
+        :param app_id：应用标识
+        :param act_id：活动标识
+        :param user_id：用户标识
+        :param open_id：open_id
         :param order_no：订单号
-        :param order_status：订单状态
         :param nick_name：用户昵称
-        :return str
+        :param real_name：用户名字
+        :param telephone：联系电话
+        :param address：收货地址
+        :param order_status：订单状态（-1未付款-2付款中0未发货1已发货2不予发货3已退款4交易成功）
+        :param create_date_start：订单创建时间开始
+        :param create_date_end：订单创建时间结束
+        :param page_size：页大小
+        :param page_index：页索引
+        :return
         :last_editors: HuangJianYi
         """
         app_id = self.get_app_id()
@@ -311,6 +321,7 @@ class PrizeRosterExportHandler(TaoBaseHandler):
     def get_async(self):
         """
         :description: 导出用户中奖记录列表
+        :param app_id：应用标识
         :param act_id：活动标识
         :param module_id：活动模块标识
         :param user_id：用户标识
