@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-02 14:25:02
-@LastEditTime: 2021-08-18 18:15:09
+@LastEditTime: 2021-09-07 09:31:43
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -104,6 +104,7 @@ class DeletePriceGearHandler(TaoBaseHandler):
         invoke_result_data = price_base_model.update_price_gear_status(app_id, act_id, price_gear_id, 1)
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
+        self.create_operation_log(OperationType.delete.value, "price_gear_tb", "DeletePriceGearHandler", None, price_gear_id)
         self.response_json_success()
 
 
@@ -129,6 +130,7 @@ class ReviewPriceGearHandler(TaoBaseHandler):
         invoke_result_data = price_base_model.update_price_gear_status(app_id, act_id, price_gear_id, 0)
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
+        self.create_operation_log(OperationType.review.value, "price_gear_tb", "ReviewPriceGearHandler", None, price_gear_id)
         self.response_json_success()
 
 
@@ -143,6 +145,8 @@ class CheckPriceGearHandler(TaoBaseHandler):
         :param app_id：应用标识
         :param act_id：活动标识
         :param price_gear_id：价格档位标识
+        :param goods_id：商品ID
+        :param sku_id：sku_id
         :return: response_json_success
         :last_editors: HuangJianYi
         """
