@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-03 15:42:53
-@LastEditTime: 2021-08-31 16:04:39
+@LastEditTime: 2021-09-06 18:45:26
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -102,8 +102,8 @@ class SaveActPrizeHandler(TaoBaseHandler):
         s3 = self.get_param("s3")
         s4 = self.get_param("s4")
         s5 = self.get_param("s5")
-        d1 = self.get_param("d1")
-        d2 = self.get_param("d2")
+        d1 = self.get_param("d1", "1900-01-01 00:00:00")
+        d2 = self.get_param("d2", "1900-01-01 00:00:00")
 
         prize_base_model = PrizeBaseModel(context=self)
         invoke_result_data = prize_base_model.save_act_prize(app_id, act_id, module_id, prize_id, prize_name, prize_title, prize_pic, prize_detail_json, goods_id, goods_code, goods_code_list, goods_type, prize_type, prize_price, probability, chance, prize_limit, is_prize_notice, prize_total, is_surplus, lottery_type, tag_name, tag_id, is_sku, sku_json, sort_index, is_release, ascription_type, i1, i2, i3, i4, i5, s1, s2, s3, s4, s5, d1, d2)
