@@ -2,7 +2,7 @@
 """
 :Author: HuangJianYi
 :Date: 2020-11-16 13:44:20
-@LastEditTime: 2021-09-03 13:31:04
+@LastEditTime: 2021-09-06 19:26:33
 @LastEditors: HuangJianYi
 :description: 
 """
@@ -18,6 +18,7 @@ class StatReportListHandler(TaoBaseHandler):
     def get_async(self):
         """
         :description: 报表数据列表(表格) 
+        :param app_id：应用标识
         :param act_id：活动标识
         :param module_id：活动模块标识
         :param start_date：开始时间
@@ -25,13 +26,14 @@ class StatReportListHandler(TaoBaseHandler):
         :return list
         :last_editors: HuangJianYi
         """
+        app_id = self.get_app_id()
         act_id = int(self.get_param("act_id", 0))
         module_id = int(self.get_param("module_id", 0))
         start_date = self.get_param("start_date")
         end_date = self.get_param("end_date")
 
         stat_base_model = StatBaseModel(context=self)
-        return self.response_json_success(self.business_process_executed(stat_base_model.get_stat_report_list(act_id, module_id, start_date, end_date)))
+        return self.response_json_success(self.business_process_executed(stat_base_model.get_stat_report_list(app_id, act_id, module_id, start_date, end_date)))
 
     def business_process_executed(self, stat_report_list):
         """
@@ -51,6 +53,7 @@ class TrendReportListHandler(TaoBaseHandler):
     def get_async(self):
         """
         :description: 报表数据列表(趋势图) 
+        :param app_id：应用标识
         :param act_id：活动标识
         :param module_id：活动模块标识
         :param start_date：开始时间
@@ -58,13 +61,14 @@ class TrendReportListHandler(TaoBaseHandler):
         :return list
         :last_editors: HuangJianYi
         """
+        app_id = self.get_app_id()
         act_id = int(self.get_param("act_id", 0))
         module_id = int(self.get_param("module_id", 0))
         start_date = self.get_param("start_date")
         end_date = self.get_param("end_date")
 
         stat_base_model = StatBaseModel(context=self)
-        return self.response_json_success(self.business_process_executed(stat_base_model.get_trend_report_list(act_id, module_id, start_date, end_date)))
+        return self.response_json_success(self.business_process_executed(stat_base_model.get_trend_report_list(app_id, act_id, module_id, start_date, end_date)))
 
     def business_process_executed(self, trend_report_list):
         """
