@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-02 09:03:41
-@LastEditTime: 2021-08-19 16:05:26
+@LastEditTime: 2021-09-07 09:44:15
 @LastEditors: HuangJianYi
 @Description: 主题皮肤
 """
@@ -55,13 +55,14 @@ class UpdateThemeHandler(TaoBaseHandler):
         :param app_id：应用标识
         :param act_id：活动标识
         :param theme_id：主题标识
+        :param is_module：是否更新活动模块皮肤 True是False否
         :return: 
         :last_editors: HuangJianYi
         """
         app_id = self.get_app_id()
         act_id = int(self.get_param("act_id", 0))
         theme_id = int(self.get_param("theme_id", 0))
-        is_module = int(self.get_param("is_module", 1))
+        is_module = self.get_param("is_module", True)
 
         theme_base_model = ThemeBaseModel(context=self)
         invoke_result_data = theme_base_model.update_act_theme_and_skin(app_id, act_id, theme_id, is_module)
