@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-07-27 10:52:51
-@LastEditTime: 2021-08-18 18:17:37
+@LastEditTime: 2021-09-07 10:05:32
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -108,8 +108,7 @@ class UpdateUserStatusByBlackHandler(TaoBaseHandler):
         :description: 更新用户状态
         :param app_id：应用标识
         :param act_id：活动标识
-        :param user_id：用户标识
-        :param is_black：是否进入黑名单管理模式（1是0否）
+        :param tb_user_id：用户标识
         :return: 
         :last_editors: HuangJianYi
         """
@@ -131,14 +130,14 @@ class AuditUserBlackHandler(TaoBaseHandler):
     def get_async(self):
         """
         :description: 审核黑名单状态
-        :param black_id：用户黑名单管理id
+        :param black_id：用户黑名单管理标识
         :param audit_status：审核状态(0黑名单1申请中2同意3拒绝)
         :return: response_json_success
         :last_editors: HuangJianYi
         """
+        app_id = self.get_app_id()
         black_id = int(self.get_param("black_id", 0))
         audit_status = int(self.get_param("audit_status", 0))
-        app_id = self.get_app_id()
         user_base_model = UserBaseModel(context=self)
         invoke_result_data = user_base_model.audit_user_black(app_id, black_id, audit_status)
         if invoke_result_data.success == False:
@@ -156,23 +155,27 @@ class UserBlackListHandler(TaoBaseHandler):
         :description: 获取黑名单管理列表
         :param app_id：应用标识
         :param act_id：活动标识
-        :param audit_status：状态
+        :param audit_status：审核状态(0黑名单1申请中2同意3拒绝)
+        :param tb_user_id：用户标识
+        :param start_date：开始时间
+        :param end_date：结束时间
         :param nick_name：用户昵称
-        :param create_date_start：创建时间开始
-        :param create_date_end：创建时间结束
+        :param user_open_id：open_id
+        :param page_size：条数
+        :param page_index：页数
         :return: list
         :last_editors: HuangJianYi
         """
         app_id = self.get_app_id()
         act_id = int(self.get_param("act_id", 0))
-        page_size = int(self.get_param("page_size", 20))
-        page_index = int(self.get_param("page_index", 0))
         audit_status = int(self.get_param("audit_status", -1))
         tb_user_id = int(self.get_param("tb_user_id", 0))
         user_nick = self.get_param("nick_name")
         open_id = self.get_param("user_open_id")
         start_date = self.get_param("start_date")
         end_date = self.get_param("end_date")
+        page_size = int(self.get_param("page_size", 20))
+        page_index = int(self.get_param("page_index", 0))
 
         user_base_model = UserBaseModel(context=self)
         self.response_json_success(user_base_model.get_black_list(app_id, act_id, page_size, page_index, audit_status, tb_user_id, start_date, end_date, user_nick, open_id))
@@ -188,26 +191,27 @@ class UpdateUserAssetHandler(TaoBaseHandler):
         :description: 变更资产
         :param app_id：应用标识
         :param act_id：活动标识
-        :param user_id：用户标识
+        :param tb_user_id：用户标识
         :param asset_type：资产类型
         :param asset_value：变更的资产值
+        :param asset_object_id：资产对象标识
         :return: response_json_success
         :last_editors: HuangJianYi
         """
         app_id = self.get_app_id()
         act_id = int(self.get_param("act_id", 0))
-        tb_user_id = int(self.get_param("tb_user_id", 0))
+        user_id = int(self.get_param("tb_user_id", 0))
         asset_type = int(self.get_param("asset_type", 0))
         asset_value = int(self.get_param("asset_value", 0))
         asset_object_id = self.get_param("asset_object_id")
 
         user_base_model = UserBaseModel(context=self)
-        user_info_dict = user_base_model.get_user_info_dict(app_id, act_id, tb_user_id)
+        user_info_dict = user_base_model.get_user_info_dict(app_id, act_id, user_id)
         if not user_info_dict:
             return self.response_json_error("error","用户信息不存在")
 
         asset_base_model = AssetBaseModel(context=self)
-        invoke_result_data = asset_base_model.update_user_asset(app_id, act_id, 0, tb_user_id, user_info_dict["open_id"], user_info_dict["user_nick"], asset_type, asset_value, asset_object_id, 3, "", "手动配置", "手动配置")
+        invoke_result_data = asset_base_model.update_user_asset(app_id, act_id, 0, user_id, user_info_dict["open_id"], user_info_dict["user_nick"], asset_type, asset_value, asset_object_id, 3, "", "手动配置", "手动配置")
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code,invoke_result_data.error_message)
         self.response_json_success()
@@ -223,20 +227,19 @@ class BatchUpdateUserAssetHandler(TaoBaseHandler):
         :description: 批量变更资产
         :param app_id：应用标识
         :param act_id：活动标识
-        :param user_id：用户标识
+        :param tb_user_id：用户标识
         :param asset_object_json：变更的资产值列表
         :return: response_json_success
         :last_editors: HuangJianYi
         """
         app_id = self.get_app_id()
         act_id = int(self.get_param("act_id", 0))
-        tb_user_id = int(self.get_param("tb_user_id", 0))
-        asset_type = int(self.get_param("asset_type", 0))
+        user_id = int(self.get_param("tb_user_id", 0))
         #{"asset_type":0,"asset_object_id":"","asset_value":0}
         asset_object_json = self.get_param("asset_object_json")
 
         user_base_model = UserBaseModel(context=self)
-        user_info_dict = user_base_model.get_user_info_dict(app_id, act_id, tb_user_id)
+        user_info_dict = user_base_model.get_user_info_dict(app_id, act_id, user_id)
         if not user_info_dict:
             return self.response_json_error("error", "用户信息不存在")
 
@@ -244,7 +247,7 @@ class BatchUpdateUserAssetHandler(TaoBaseHandler):
         asset_object_json = SevenHelper.json_loads(asset_object_json)
         asset_object_ids = ""
         for asset_object in asset_object_json:
-            invoke_result_data = asset_base_model.update_user_asset(app_id, act_id, 0, tb_user_id, user_info_dict["open_id"], user_info_dict["user_nick"], int(asset_object["asset_type"]), int(asset_object["asset_value"]), asset_object["asset_object_id"], 3, "", "手动配置", "手动配置")
+            invoke_result_data = asset_base_model.update_user_asset(app_id, act_id, 0, user_id, user_info_dict["open_id"], user_info_dict["user_nick"], int(asset_object["asset_type"]), int(asset_object["asset_value"]), asset_object["asset_object_id"], 3, "", "手动配置", "手动配置")
             if invoke_result_data.success == False:
                 return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message, asset_object_ids)
             else:
@@ -288,7 +291,7 @@ class AssetLogListHandler(TaoBaseHandler):
         user_nick = self.get_param("nick_name")
         start_date = self.get_param("start_date")
         end_date = self.get_param("end_date")
-        source_type = int(self.get_param("source_type", -1))
+        source_type = int(self.get_param("source_type", 0))
         source_object_id = self.get_param("source_object_id")
         asset_type = int(self.get_param("asset_type", 0))
         asset_object_id = self.get_param("asset_object_id")
