@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-07-15 17:17:08
-@LastEditTime: 2021-08-19 11:35:02
+@LastEditTime: 2021-09-02 18:50:56
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -25,7 +25,7 @@ class AssetLog:
 
     def __init__(self):
         super(AssetLog, self).__init__()
-        self.id = 0  # id(act_id+user_id+guid)md5int生成
+        self.id = 0  # id
         self.app_id = ""  # 应用标识
         self.act_id = 0  # 活动标识
         self.module_id = 0  # 活动模块标识
