@@ -2,7 +2,7 @@
 """
 :Author: HuangJianYi
 :Date: 2020-06-02 14:32:40
-@LastEditTime: 2021-09-03 10:20:56
+@LastEditTime: 2021-09-07 15:22:47
 @LastEditors: HuangJianYi
 :description: 枚举类
 """
@@ -46,3 +46,5 @@ class TaskType(Enum):
     browse_live_room = 11
     # 浏览会场/专题，格式：[{"id":"","reward_value":0,"link_url":"","satisfy_num":1,"limit_num":1,"asset_object_id":""}]
     browse_special_topic = 12
+    # 累计签到，格式：{"day_list":{"1": 0, "2": 0, "3": 0, "4": 0, "5": 0, "6": 0, "7": 0},"asset_object_id":"","is_loop":1}
+    cumulative_sign = 13
