@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-09 09:24:43
-@LastEditTime: 2021-09-06 14:10:38
+@LastEditTime: 2021-09-06 17:26:46
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -612,8 +612,9 @@ class OrderBaseModel(FrameBaseModel):
                         if result == True and buy_num > 0: 
                             asset_base_model = AssetBaseModel(context=self.context)
                             invoke_result_data.data = {}
+                            invoke_result_data.data["asset_list"] = []
                             for item in tao_pay_order_list:       
-                                only_id =  f"sync_order_" + str(item.sub_pay_order_no)
+                                only_id = str(item.sub_pay_order_no)
                                 asset_invoke_result_data = asset_base_model.update_user_asset(app_id,act_id,module_id,user_id,user_info_dict["open_id"],user_info_dict["user_nick"],asset_type,item.buy_num,item.asset_object_id,1,"","","购买",only_id,handler_name,request_code,info_json={})
                                 if asset_invoke_result_data.success == False:
                                     invoke_result_data.success = False
@@ -627,9 +628,9 @@ class OrderBaseModel(FrameBaseModel):
                                     data["asset_object_id"] = item.asset_object_id
                                     data["buy_num"] = item.buy_num
                                     invoke_result_data.data["asset_list"].append(data)
-                                invoke_result_data.data["buy_num"] = buy_num
-                                invoke_result_data.data["pay_price"] = pay_price
-                                invoke_result_data.data["pay_num"] = pay_num
+                            invoke_result_data.data["buy_num"] = buy_num
+                            invoke_result_data.data["pay_price"] = pay_price
+                            invoke_result_data.data["pay_num"] = pay_num
                     
                         else:
                             invoke_result_data.success = False
