@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-04 13:41:15
-@LastEditTime: 2021-08-26 10:29:53
+@LastEditTime: 2021-09-07 10:09:55
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -75,13 +75,13 @@ class PrizeBaseModel():
         order_by = "sort_index desc,id asc"
         condition = "app_id=%s and act_id=%s"
         params = [app_id,act_id]
-        if ascription_type !=-1:
+        if ascription_type !=0:
             condition += " and ascription_type=%s"
             params.append(is_del)
         if is_del !=-1:
             condition += " and is_del=%s"
             params.append(is_del)
-        if module_id !=-1:
+        if module_id !=0:
             condition += " and module_id=%s"
             params.append(module_id)
         if prize_name:
@@ -277,7 +277,7 @@ class PrizeBaseModel():
             invoke_result_data.error_message = "活动奖品信息不存在"
             return invoke_result_data
         is_release = 0 if is_del == 1 else 1
-        modify_date = self.get_now_datetime()
+        modify_date = SevenHelper.get_now_datetime()
         invoke_result_data.success = act_prize_model.update_table("is_del=%s,is_release=%s,modify_date=%s", "id=%s", [is_del, is_release, modify_date, modify_date, prize_id])
         self._delete_act_prize_dependency_key(act_prize_dict.act_id,prize_id)
         return invoke_result_data
