@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-07-22 11:10:20
-@LastEditTime: 2021-09-06 11:31:24
+@LastEditTime: 2021-09-06 19:40:54
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -403,12 +403,12 @@ class UserBaseModel(FrameBaseModel):
                 user_black.user_nick = user_info.user_nick
                 user_black.black_type = 2
                 user_black.refund_order_data = []
-                user_black.create_date = self.get_now_datetime()
+                user_black.create_date = SevenHelper.get_now_datetime()
                 user_black_model.add_entity(user_black)
             else:
                 user_black.audit_status = 0
                 user_black.black_type = 2
-                user_black.create_date = self.get_now_datetime()
+                user_black.create_date = SevenHelper.get_now_datetime()
                 user_black_model.update_entity(user_black)
 
             result = db_transaction.commit_transaction()
