@@ -2,7 +2,7 @@
 """
 :Author: HuangJianYi
 :Date: 2020-04-16 14:38:22
-@LastEditTime: 2021-09-03 13:35:52
+@LastEditTime: 2021-09-06 18:07:11
 @LastEditors: HuangJianYi
 :Description: 基础路由   业务方可以直接使用语句 handlers.extend(seven_cloudapp_frame.route.seven_cloudapp_frame_route()) 引入
 """
@@ -74,12 +74,13 @@ def seven_cloudapp_frame_route():
         (r"/server/add_act_info", act_s.AddActInfoHandler),  #添加活动
         (r"/server/update_act_info", act_s.UpdateActInfoHandler),  #修改活动
         (r"/server/act_info_list", act_s.ActInfoListHandler),  #活动列表
-        (r"/server/act_info", act_s.ActInfoHandler),  #单条活动
+        (r"/server/act_info", act_s.ActInfoHandler),  #单条活动信息
         (r"/server/delete_act_info", act_s.DeleteActInfoHandler),  #删除活动（假删除）
         (r"/server/review_act_info", act_s.ReviewActInfoHandler),  #还原活动
         (r"/server/release_act_info", act_s.ReleaseActInfoHandler),  #上下架活动
         (r"/server/create_act_qrcode", act_s.CreateActQrCodeHandler),  #生成小程序二维码
         (r"/server/save_act_module", module_s.SaveActModuleHandler),  #保存活动模块信息（保存新增和修改）
+        (r"/server/act_module", module_s.ActModuleHandler),  #单条活动模块信息
         (r"/server/act_module_list", module_s.ActModuleListHandler),  #活动模块列表
         (r"/server/delete_act_module", module_s.DeleteActModuleHandler),  #删除活动模块（假删除）
         (r"/server/review_act_module", module_s.ReviewActModuleHandler),  #还原活动模块
